#!/usr/bin/python3

from sys import argv

fn_inp = argv[1] if len(argv) > 1 else 'iris.rbf'
fn_out = argv[2] if len(argv) > 2 else 'irisrbf.mp'

with open(fn_inp, 'r') as inp:
    ctrs  = []
    radii = []
    wgts  = []
    state = 0
    for line in inp:
        line = line.rstrip('\r\n')
        for c in '{}[]=,':
            line = line.replace(c, ' ')
        if state == 0:          # searching for 'params'
            if line.startswith('  params'):  state = 1
            else:                            continue
        if state == 1:          # collecting hidden layer parameters
            if line[-1] == ';': line = line[:-1]; state = 2
            flds = [f for f in line.split() if len(f) > 0]
            if flds[0] == 'params': flds = flds[1:]
            flds = [float(f) for f in flds]
            if len(flds) <= 1: radii.append(flds[0])
            else:              ctrs.append(flds)
            continue
        if state == 2:          # searching for 'weights'
            if line.startswith('  weights'): state = 3
            else:                            continue
        if state == 3:          # collecting hidden layer parameters
            if line[-1] == ';': line = line[:-1]; state = 4
            flds = [f for f in line.split() if len(f) > 0]
            if flds[0] == 'weights': flds = flds[1:]
            wgts.append([float(f) for f in flds])
            continue

with open(fn_out, 'w') as out:
    for c,r in zip(ctrs,radii):
        out.write('  vardef iris (expr p) =\n')
        out.write('    save u, v, t; numeric u, v, t;\n')
        out.write('    u = (xpart p) %+6f;\n' % -c[0])
        out.write('    v = (ypart p) %+6f;\n' % -c[1])
        out.write('    t = u*u+v*v;\n')
        out.write('    if t < 4: mexp(-128/%.6f*t) else: 0 fi\n' % r)
        out.write('  enddef;\n\n')
    for wv in wgts:
        out.write('  vardef iris (expr p) =\n')
        out.write('    save u, v, s, t; numeric u, v, s, t; s = 0;\n')
        for c,r,w in zip(ctrs,radii,wv[:-1]):
            out.write('    u := (xpart p) %+6f;\n' % -c[0])
            out.write('    v := (ypart p) %+6f;\n' % -c[1])
            out.write('    t := u*u+v*v;\n')
            out.write('    if t < 4: s := s +mexp(-128/%.6f*t); fi\n' % r)
        out.write('    s %+.6f\n' % -wv[-1])
        out.write('  enddef;\n\n')
        
