#-----------------------------------------------------------------------
# File    : rbf.mak
# Contents: commands to build radial basis function network programs
# Author  : Christian Borgelt
# History : 2004.09.14 file created
#           2006.07.20 adapted to Visual Studio 8
#           2007.03.16 special matrix versions removed
#           2016.04.20 completed dependencies on header files
#-----------------------------------------------------------------------
THISDIR  = ..\..\rbf\src
UTILDIR  = ..\..\util\src
MATHDIR  = ..\..\math\src
MATDIR   = ..\..\matrix\src
TABLEDIR = ..\..\table\src
CLSDIR   = ..\..\cluster\src

CC       = cl.exe
DEFS     = /D WIN32 /D NDEBUG /D _CONSOLE /D _CRT_SECURE_NO_WARNINGS
CFLAGS   = /nologo /W3 /O2 /GS- $(DEFS) /c
INCS     = /I $(UTILDIR) /I $(MATHDIR) /I $(MATDIR) /I $(TABLEDIR) \
           /I $(CLSDIR)

LD       = link.exe
LDFLAGS  = /nologo /subsystem:console /incremental:no
LIBS     = 

HDRS_1   = $(UTILDIR)\fntypes.h    $(UTILDIR)\nstats.h     \
           $(UTILDIR)\scanner.h    $(MATHDIR)\radfn.h      \
		   $(MATDIR)\matrix.h      $(TABLEDIR)\attset.h    \
		   $(TABLEDIR)\attmap.h    $(TABLEDIR)\table.h     \
           $(CLSDIR)\cluster.h
HDRS     = $(HDRS_1)               $(UTILDIR)\error.h      \
           $(UTILDIR)\tabread.h    $(UTILDIR)\tabwrite.h   \
           rbf.h
OBJS     = $(UTILDIR)\arrays.obj   $(UTILDIR)\escape.obj   \
           $(UTILDIR)\tabread.obj  $(UTILDIR)\tabwrite.obj \
           $(UTILDIR)\scanner.obj  $(UTILDIR)\nst_pars.obj \
           $(UTILDIR)\random.obj   $(MATHDIR)\gamma.obj    \
           $(MATHDIR)\radfn.obj    $(MATDIR)\mat_rdwr.obj  \
           $(MATDIR)\matrix2.obj   $(MATDIR)\matrix3.obj   \
           $(TABLEDIR)\attset1.obj $(TABLEDIR)\attset2.obj \
           $(TABLEDIR)\attset3.obj $(TABLEDIR)\attmap.obj  \
           $(TABLEDIR)\table1.obj  $(TABLEDIR)\tab2rm.obj  \
           $(CLSDIR)\cluster1.obj  $(CLSDIR)\cluster2.obj  \
           rbf.obj
RBFT_O   = $(OBJS)                 $(UTILDIR)\params.obj   \
           $(CLSDIR)\cluster4.obj  rbft.obj
RBFX_O   = $(OBJS) rbfx.obj
PRGS     = rbft.exe rbfx.exe

#-----------------------------------------------------------------------
# Build Programs
#-----------------------------------------------------------------------
all:          $(PRGS)

rbft.exe:     $(RBFT_O) rbf.mak
	$(LD) $(LDFLAGS) $(RBFT_O) $(LIBS) /out:$@

rbfx.exe:     $(RBFX_O) rbf.mak
	$(LD) $(LDFLAGS) $(RBFX_O) $(LIBS) /out:$@

#-----------------------------------------------------------------------
# Main Programs
#-----------------------------------------------------------------------
rbft.obj:     $(HDRS) $(UTILDIR)\random.h $(UTILDIR)\params.h
rbft.obj:     rbft.c rbf.mak
	$(CC) $(CFLAGS) $(INCS) rbft.c /Fo$@

rbfx.obj:     $(HDRS)
rbfx.obj:     rbfx.c rbf.mak
	$(CC) $(CFLAGS) $(INCS) rbfx.c /Fo$@

#-----------------------------------------------------------------------
# Radial Basis Function Network Management
#-----------------------------------------------------------------------
rbf.obj:      $(HDRS_1)
rbf.obj:      $(MHDRS) rbf.c rbf.mak
	$(CC) $(CFLAGS) $(INCS) /D RBF_PARSE rbf.c /Fo$@

#-----------------------------------------------------------------------
# External Modules
#-----------------------------------------------------------------------
$(MATHDIR)\gamma.obj:
	cd $(MATHDIR)
	$(MAKE) /f math.mak gamma.obj
	cd $(THISDIR)
$(MATHDIR)\radfn.obj:
	cd $(MATHDIR)
	$(MAKE) /f math.mak radfn.obj
	cd $(THISDIR)
$(UTILDIR)\arrays.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak arrays.obj
	cd $(THISDIR)
$(UTILDIR)\nst_pars.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak nst_pars.obj
	cd $(THISDIR)
$(UTILDIR)\escape.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak escape.obj
	cd $(THISDIR)
$(UTILDIR)\tabread.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak tabread.obj
	cd $(THISDIR)
$(UTILDIR)\tabwrite.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak tabwrite.obj
	cd $(THISDIR)
$(UTILDIR)\scanner.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak scanner.obj
	cd $(THISDIR)
$(UTILDIR)\random.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak random.obj
	cd $(THISDIR)
$(UTILDIR)\params.obj:
	cd $(UTILDIR)
	$(MAKE) /f util.mak params.obj
	cd $(THISDIR)
$(MATDIR)\mat_rdwr.obj:
	cd $(MATDIR)
	$(MAKE) /f matrix.mak mat_rdwr.obj
	cd $(THISDIR)
$(MATDIR)\matrix1.obj:
	cd $(MATDIR)
	$(MAKE) /f matrix.mak matrix1.obj
	cd $(THISDIR)
$(MATDIR)\matrix2.obj:
	cd $(MATDIR)
	$(MAKE) /f matrix.mak matrix2.obj
	cd $(THISDIR)
$(MATDIR)\matrix3.obj:
	cd $(MATDIR)
	$(MAKE) /f matrix.mak matrix3.obj
	cd $(THISDIR)
$(TABLEDIR)\attset1.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak attset1.obj
	cd $(THISDIR)
$(TABLEDIR)\attset2.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak attset2.obj
	cd $(THISDIR)
$(TABLEDIR)\attset3.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak attset3.obj
	cd $(THISDIR)
$(TABLEDIR)\attmap.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak attmap.obj
	cd $(THISDIR)
$(TABLEDIR)\table1.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak table1.obj
	cd $(THISDIR)
$(TABLEDIR)\tab2rm.obj:
	cd $(TABLEDIR)
	$(MAKE) /f table.mak tab2rm.obj
	cd $(THISDIR)
$(CLSDIR)\cluster1.obj:
	cd $(CLSDIR)
	$(MAKE) /f cluster.mak cluster1.obj
	cd $(THISDIR)
$(CLSDIR)\cluster2.obj:
	cd $(CLSDIR)
	$(MAKE) /f cluster.mak cluster2.obj
	cd $(THISDIR)
$(CLSDIR)\cluster4.obj:
	cd $(CLSDIR)
	$(MAKE) /f cluster.mak cluster4.obj
	cd $(THISDIR)

#-----------------------------------------------------------------------
# Install
#-----------------------------------------------------------------------
install:
	-@copy *.exe ..\..\..\bin

#-----------------------------------------------------------------------
# Clean up
#-----------------------------------------------------------------------
clean:
	$(MAKE) /f rbf.mak localclean
	cd $(MATHDIR)
	$(MAKE) /f math.mak clean
	cd $(UTILDIR)
	$(MAKE) /f util.mak clean
	cd $(MATDIR)
	$(MAKE) /f matrix.mak localclean
	cd $(TABLEDIR)
	$(MAKE) /f table.mak localclean
	cd $(CLSDIR)
	$(MAKE) /f cluster.mak localclean
	cd $(THISDIR)

localclean:
	-@erase /Q *~ *.obj *.idb *.pch $(PRGS)
